<a id="types-aiobotocore-es"></a>

# types-aiobotocore-es

[![PyPI - types-aiobotocore-es](https://img.shields.io/pypi/v/types-aiobotocore-es.svg?color=blue)](https://pypi.org/project/types-aiobotocore-es)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-es.svg?color=blue)](https://pypi.org/project/types-aiobotocore-es)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-es?color=blue)](https://pypistats.org/packages/types-aiobotocore-es)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.ElasticsearchService 2.3.3](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/es.html#ElasticsearchService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.6.1](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-es docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_es/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-es](#types-aiobotocore-es)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ElasticsearchService`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ElasticsearchService` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[es]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[es]'


# standalone installation
python -m pip install types-aiobotocore-es
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-es
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[es]` in your environment:

```bash
python -m pip install 'types-aiobotocore[es]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[es]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[es]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[es]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[es]` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[es]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[es]` in your environment:

```bash
python -m pip install 'types-aiobotocore[es]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[es]` in your environment:

```bash
python -m pip install 'types-aiobotocore[es]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ElasticsearchServiceClient` provides annotations for
`session.create_client("es")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_es import ElasticsearchServiceClient

session = get_session()
async with session.create_client("es") as client:
    client: ElasticsearchServiceClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_es.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_es import ElasticsearchServiceClient
from types_aiobotocore_es.paginator import (
    DescribeReservedElasticsearchInstanceOfferingsPaginator,
    DescribeReservedElasticsearchInstancesPaginator,
    GetUpgradeHistoryPaginator,
    ListElasticsearchInstanceTypesPaginator,
    ListElasticsearchVersionsPaginator,
)

session = get_session()
async with session.create_client("es") as client:
    client: ElasticsearchServiceClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_reserved_elasticsearch_instance_offerings_paginator: DescribeReservedElasticsearchInstanceOfferingsPaginator = client.get_paginator("describe_reserved_elasticsearch_instance_offerings")
        describe_reserved_elasticsearch_instances_paginator: DescribeReservedElasticsearchInstancesPaginator = client.get_paginator("describe_reserved_elasticsearch_instances")
        get_upgrade_history_paginator: GetUpgradeHistoryPaginator = client.get_paginator("get_upgrade_history")
        list_elasticsearch_instance_types_paginator: ListElasticsearchInstanceTypesPaginator = client.get_paginator("list_elasticsearch_instance_types")
        list_elasticsearch_versions_paginator: ListElasticsearchVersionsPaginator = client.get_paginator("list_elasticsearch_versions")
    ```







### Literals

`types_aiobotocore_es.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_es.literals import (
    AutoTuneDesiredStateType,
    AutoTuneStateType,
    AutoTuneTypeType,
    DeploymentStatusType,
    DescribePackagesFilterNameType,
    DescribeReservedElasticsearchInstanceOfferingsPaginatorName,
    DescribeReservedElasticsearchInstancesPaginatorName,
    DomainPackageStatusType,
    ESPartitionInstanceTypeType,
    ESWarmPartitionInstanceTypeType,
    EngineTypeType,
    GetUpgradeHistoryPaginatorName,
    InboundCrossClusterSearchConnectionStatusCodeType,
    ListElasticsearchInstanceTypesPaginatorName,
    ListElasticsearchVersionsPaginatorName,
    LogTypeType,
    OptionStateType,
    OutboundCrossClusterSearchConnectionStatusCodeType,
    OverallChangeStatusType,
    PackageStatusType,
    PackageTypeType,
    ReservedElasticsearchInstancePaymentOptionType,
    RollbackOnDisableType,
    ScheduledAutoTuneActionTypeType,
    ScheduledAutoTuneSeverityTypeType,
    TLSSecurityPolicyType,
    TimeUnitType,
    UpgradeStatusType,
    UpgradeStepType,
    VolumeTypeType,
    ElasticsearchServiceServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)

def check_value(value: AutoTuneDesiredStateType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_es.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_es.type_defs import (
    AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    OptionStatusTypeDef,
    TagTypeDef,
    AdditionalLimitTypeDef,
    MasterUserOptionsTypeDef,
    AssociatePackageRequestRequestTypeDef,
    ScheduledAutoTuneDetailsTypeDef,
    DurationTypeDef,
    AutoTuneOptionsOutputTypeDef,
    AutoTuneStatusTypeDef,
    CancelElasticsearchServiceSoftwareUpdateRequestRequestTypeDef,
    ServiceSoftwareOptionsTypeDef,
    ChangeProgressDetailsTypeDef,
    ChangeProgressStageTypeDef,
    CognitoOptionsTypeDef,
    ColdStorageOptionsTypeDef,
    CompatibleVersionsMapTypeDef,
    DomainEndpointOptionsTypeDef,
    EBSOptionsTypeDef,
    EncryptionAtRestOptionsTypeDef,
    LogPublishingOptionTypeDef,
    NodeToNodeEncryptionOptionsTypeDef,
    SnapshotOptionsTypeDef,
    VPCOptionsTypeDef,
    DomainInformationTypeDef,
    OutboundCrossClusterSearchConnectionStatusTypeDef,
    PackageSourceTypeDef,
    DeleteElasticsearchDomainRequestRequestTypeDef,
    DeleteInboundCrossClusterSearchConnectionRequestRequestTypeDef,
    DeleteOutboundCrossClusterSearchConnectionRequestRequestTypeDef,
    DeletePackageRequestRequestTypeDef,
    DescribeDomainAutoTunesRequestRequestTypeDef,
    DescribeDomainChangeProgressRequestRequestTypeDef,
    DescribeElasticsearchDomainConfigRequestRequestTypeDef,
    DescribeElasticsearchDomainRequestRequestTypeDef,
    DescribeElasticsearchDomainsRequestRequestTypeDef,
    DescribeElasticsearchInstanceTypeLimitsRequestRequestTypeDef,
    FilterTypeDef,
    DescribePackagesFilterTypeDef,
    PaginatorConfigTypeDef,
    DescribeReservedElasticsearchInstanceOfferingsRequestRequestTypeDef,
    DescribeReservedElasticsearchInstancesRequestRequestTypeDef,
    DissociatePackageRequestRequestTypeDef,
    DomainInfoTypeDef,
    ErrorDetailsTypeDef,
    DryRunResultsTypeDef,
    ZoneAwarenessConfigTypeDef,
    VPCDerivedInfoTypeDef,
    GetCompatibleElasticsearchVersionsRequestRequestTypeDef,
    GetPackageVersionHistoryRequestRequestTypeDef,
    PackageVersionHistoryTypeDef,
    GetUpgradeHistoryRequestRequestTypeDef,
    GetUpgradeStatusRequestRequestTypeDef,
    InboundCrossClusterSearchConnectionStatusTypeDef,
    InstanceCountLimitsTypeDef,
    ListDomainNamesRequestRequestTypeDef,
    ListDomainsForPackageRequestRequestTypeDef,
    ListElasticsearchInstanceTypesRequestRequestTypeDef,
    ListElasticsearchVersionsRequestRequestTypeDef,
    ListPackagesForDomainRequestRequestTypeDef,
    ListTagsRequestRequestTypeDef,
    PurchaseReservedElasticsearchInstanceOfferingRequestRequestTypeDef,
    RecurringChargeTypeDef,
    RejectInboundCrossClusterSearchConnectionRequestRequestTypeDef,
    RemoveTagsRequestRequestTypeDef,
    SAMLIdpTypeDef,
    StartElasticsearchServiceSoftwareUpdateRequestRequestTypeDef,
    StorageTypeLimitTypeDef,
    UpgradeElasticsearchDomainRequestRequestTypeDef,
    UpgradeStepItemTypeDef,
    EmptyResponseMetadataTypeDef,
    GetUpgradeStatusResponseTypeDef,
    ListElasticsearchInstanceTypesResponseTypeDef,
    ListElasticsearchVersionsResponseTypeDef,
    PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef,
    AccessPoliciesStatusTypeDef,
    AdvancedOptionsStatusTypeDef,
    ElasticsearchVersionStatusTypeDef,
    AddTagsRequestRequestTypeDef,
    ListTagsResponseTypeDef,
    AutoTuneDetailsTypeDef,
    AutoTuneMaintenanceScheduleTypeDef,
    CancelElasticsearchServiceSoftwareUpdateResponseTypeDef,
    StartElasticsearchServiceSoftwareUpdateResponseTypeDef,
    UpgradeElasticsearchDomainResponseTypeDef,
    ChangeProgressStatusDetailsTypeDef,
    CognitoOptionsStatusTypeDef,
    GetCompatibleElasticsearchVersionsResponseTypeDef,
    DomainEndpointOptionsStatusTypeDef,
    EBSOptionsStatusTypeDef,
    EncryptionAtRestOptionsStatusTypeDef,
    LogPublishingOptionsStatusTypeDef,
    NodeToNodeEncryptionOptionsStatusTypeDef,
    SnapshotOptionsStatusTypeDef,
    CreateOutboundCrossClusterSearchConnectionRequestRequestTypeDef,
    CreateOutboundCrossClusterSearchConnectionResponseTypeDef,
    OutboundCrossClusterSearchConnectionTypeDef,
    CreatePackageRequestRequestTypeDef,
    UpdatePackageRequestRequestTypeDef,
    DescribeInboundCrossClusterSearchConnectionsRequestRequestTypeDef,
    DescribeOutboundCrossClusterSearchConnectionsRequestRequestTypeDef,
    DescribePackagesRequestRequestTypeDef,
    DescribeReservedElasticsearchInstanceOfferingsRequestDescribeReservedElasticsearchInstanceOfferingsPaginateTypeDef,
    DescribeReservedElasticsearchInstancesRequestDescribeReservedElasticsearchInstancesPaginateTypeDef,
    GetUpgradeHistoryRequestGetUpgradeHistoryPaginateTypeDef,
    ListElasticsearchInstanceTypesRequestListElasticsearchInstanceTypesPaginateTypeDef,
    ListElasticsearchVersionsRequestListElasticsearchVersionsPaginateTypeDef,
    ListDomainNamesResponseTypeDef,
    DomainPackageDetailsTypeDef,
    PackageDetailsTypeDef,
    ElasticsearchClusterConfigTypeDef,
    VPCDerivedInfoStatusTypeDef,
    GetPackageVersionHistoryResponseTypeDef,
    InboundCrossClusterSearchConnectionTypeDef,
    InstanceLimitsTypeDef,
    ReservedElasticsearchInstanceOfferingTypeDef,
    ReservedElasticsearchInstanceTypeDef,
    SAMLOptionsInputTypeDef,
    SAMLOptionsOutputTypeDef,
    StorageTypeTypeDef,
    UpgradeHistoryTypeDef,
    AutoTuneTypeDef,
    AutoTuneOptionsInputTypeDef,
    AutoTuneOptionsTypeDef,
    DescribeDomainChangeProgressResponseTypeDef,
    DeleteOutboundCrossClusterSearchConnectionResponseTypeDef,
    DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef,
    AssociatePackageResponseTypeDef,
    DissociatePackageResponseTypeDef,
    ListDomainsForPackageResponseTypeDef,
    ListPackagesForDomainResponseTypeDef,
    CreatePackageResponseTypeDef,
    DeletePackageResponseTypeDef,
    DescribePackagesResponseTypeDef,
    UpdatePackageResponseTypeDef,
    ElasticsearchClusterConfigStatusTypeDef,
    AcceptInboundCrossClusterSearchConnectionResponseTypeDef,
    DeleteInboundCrossClusterSearchConnectionResponseTypeDef,
    DescribeInboundCrossClusterSearchConnectionsResponseTypeDef,
    RejectInboundCrossClusterSearchConnectionResponseTypeDef,
    DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef,
    DescribeReservedElasticsearchInstancesResponseTypeDef,
    AdvancedSecurityOptionsInputTypeDef,
    AdvancedSecurityOptionsTypeDef,
    LimitsTypeDef,
    GetUpgradeHistoryResponseTypeDef,
    DescribeDomainAutoTunesResponseTypeDef,
    AutoTuneOptionsStatusTypeDef,
    CreateElasticsearchDomainRequestRequestTypeDef,
    UpdateElasticsearchDomainConfigRequestRequestTypeDef,
    AdvancedSecurityOptionsStatusTypeDef,
    ElasticsearchDomainStatusTypeDef,
    DescribeElasticsearchInstanceTypeLimitsResponseTypeDef,
    ElasticsearchDomainConfigTypeDef,
    CreateElasticsearchDomainResponseTypeDef,
    DeleteElasticsearchDomainResponseTypeDef,
    DescribeElasticsearchDomainResponseTypeDef,
    DescribeElasticsearchDomainsResponseTypeDef,
    DescribeElasticsearchDomainConfigResponseTypeDef,
    UpdateElasticsearchDomainConfigResponseTypeDef,
)

def get_structure() -> AcceptInboundCrossClusterSearchConnectionRequestRequestTypeDef:
    return {
      ...
    }
```

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

## What's new

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

## Versioning

`types-aiobotocore-es` version is the same as related `aiobotocore` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_es/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
